==> verylargebits-0.1.7.tar.gz: verylargebits-0.1.7/setup.py <==
# coding: utf-8

"""Copyright(c) 2017, Very Large Bits LLC

MIT License

Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files (the "Software"), to deal in the Software
without restriction, including without limitation the rights to use, copy, modify,
merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be included in all copies
or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."""

from setuptools import setup

setup(
    name="verylargebits",
    packages=["verylargebits"],
    version="0.1.7",
    description="Python SDK for the Very Large Bits API",
    long_description="Provides an easy-to-use HTTP client for all supported Very Large Bits\
 services and authentication protocols.",
    url="https://github.com/verylargebits/sdk-python",
    download_url="https://github.com/verylargebits/sdk-python/archive/0.1.7.tar.gz",
    author="John Wells",
    author_email="john@verylargebits.com",
    maintainer="John Wells",
    maintainer_email="john@verylargebits.com",
    classifiers=[
        # See: https://pypi.python.org/pypi?:action=list_classifiers
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    zip_safe=False,
    install_requires=["pycrypto", "requests"],
    tests_require=["future", "unittest2"],
    test_suite="tests.all_tests",
)

==> verylargebits-0.1.8.tar.gz: verylargebits-0.1.8/setup.py <==
# coding: utf-8

"""Copyright(c) 2017, Very Large Bits LLC

MIT License

Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files (the "Software"), to deal in the Software
without restriction, including without limitation the rights to use, copy, modify,
merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be included in all copies
or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."""

from setuptools import setup

setup(
    name="verylargebits",
    packages=["verylargebits"],
    version="0.1.8",
    description="Python SDK for the Very Large Bits API",
    long_description="Provides an easy-to-use HTTP client for all supported Very Large Bits\
 services and authentication protocols.",
    url="https://github.com/verylargebits/sdk-python",
    download_url="https://github.com/verylargebits/sdk-python/archive/0.1.8.tar.gz",
    author="John Wells",
    author_email="john@verylargebits.com",
    maintainer="John Wells",
    maintainer_email="john@verylargebits.com",
    classifiers=[
        # See: https://pypi.python.org/pypi?:action=list_classifiers
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    zip_safe=False,
    install_requires=["pycryptodome", "requests"],
    tests_require=["future", "unittest2"],
    test_suite="tests.all_tests",
)
